/* dlvhex -- Answer-Set Programming with external interfaces.
 * Copyright (C) 2005-2007 Roman Schindlauer
 * Copyright (C) 2006-2015 Thomas Krennwallner
 * Copyright (C) 2009-2016 Peter Schüller
 * Copyright (C) 2011-2016 Christoph Redl
 * Copyright (C) 2015-2016 Tobias Kaminski
 * Copyright (C) 2015-2016 Antonius Weinzierl
 *
 * This file is part of dlvhex.
 *
 * dlvhex is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * dlvhex is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with dlvhex; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 */

/**
 * @file   DLVProcess.h
 * @author Thomas Krennwallner
 * @date
 *
 * @brief  Process interface to DLV programs.
 *
 *
 */

#if !defined(_DLVHEX_DLVPROCESS_H)
#define _DLVHEX_DLVPROCESS_H

#include "dlvhex2/Process.h"
#include "dlvhex2/ProcessBuf.h"

#include "dlvhex2/PlatformDefinitions.h"

#include <iosfwd>
#include <vector>
#include <string>
#include <cassert>

DLVHEX_NAMESPACE_BEGIN

/**
 * @brief A wrapper process for the DLV/DLVDB ASP engine.
 * @todo this class should have a name similar to DebuggingSupportChildProcess to really capture its purpose
 */
class DLVHEX_EXPORT DLVProcess : public Process
{
    protected:
        //** \brief Communication buffer. */
        ProcessBuf proc;

        /// iostreams to the dlv process
        /** \brief Input pipe. */
        std::istream* ipipe;
        /** \brief Output pipe. */
        std::ostream* opipe;

        /** \brief Executable path/name. */
        std::string executable;

        /** \brief Command line options. */
        std::vector<std::string> argv;

        /** \brief Initialize in/out streams. */
        void
            setupStreams();

    public:
        /** \brief Constructor. */
        DLVProcess();

        /** \brief Destructor. */
        virtual
            ~DLVProcess();

        virtual void
            addOption(const std::string&);

        virtual void
            setPath(const std::string&);

        virtual std::string
            path() const;

        virtual std::vector<std::string>
            commandline() const;

        virtual void
            spawn();

        virtual void
            spawn(const std::vector<std::string>&);

        virtual void
            endoffile();

        // wait for end of process
        // if kill is true, kill if not already ended
        virtual int
            close(bool kill=false);

        virtual std::ostream&
            getOutput();

        virtual std::istream&
            getInput();
};

DLVHEX_NAMESPACE_END
#endif                           // _DLVHEX_DLVPROCESS_H


// vim:expandtab:ts=4:sw=4:
// mode: C++
// End:
